Merge pi-dev-plus-aosp-without-vendor into stage-aosp-master

Bug: 79597307
Change-Id: I1654ea88799d1d23f2cd3956563451e3c7ef698c
diff --git a/Android.mk b/Android.mk
index 745a2ad..879692e 100644
--- a/Android.mk
+++ b/Android.mk
@@ -4,8 +4,12 @@
 
 LOCAL_MODULE_TAGS := optional
 
-LOCAL_STATIC_JAVA_LIBRARIES := android-support-v13
-LOCAL_STATIC_JAVA_LIBRARIES += android-ex-camera2-portability
+LOCAL_STATIC_ANDROID_LIBRARIES := \
+    android-support-v13 \
+    android-support-v4 \
+    android-support-compat
+
+LOCAL_STATIC_JAVA_LIBRARIES := android-ex-camera2-portability
 LOCAL_STATIC_JAVA_LIBRARIES += xmp_toolkit
 LOCAL_STATIC_JAVA_LIBRARIES += glide
 LOCAL_STATIC_JAVA_LIBRARIES += guava
@@ -19,13 +23,15 @@
 	$(LOCAL_PATH)/res \
 	$(LOCAL_PATH)/res_p
 
-
 include $(LOCAL_PATH)/version.mk
+
 LOCAL_AAPT_FLAGS := \
         --auto-add-overlay \
         --version-name "$(version_name_package)" \
         --version-code $(version_code_package) \
 
+LOCAL_USE_AAPT2 := true
+
 LOCAL_PACKAGE_NAME := Camera2
 
 LOCAL_SDK_VERSION := current
diff --git a/jni/Android.mk b/jni/Android.mk
index d8c66a2..8e8de57 100644
--- a/jni/Android.mk
+++ b/jni/Android.mk
@@ -26,7 +26,6 @@
 
 LOCAL_STATIC_LIBRARIES := libjpeg_static_ndk
 
-LOCAL_CFLAGS := -std=c++11
 LOCAL_CFLAGS += -ffast-math -O3 -funroll-loops
 LOCAL_CFLAGS += -Wall -Wextra -Werror
 LOCAL_ARM_MODE := arm
diff --git a/res/values-bs/strings.xml b/res/values-bs/strings.xml
index 5259559..ec6fe81 100644
--- a/res/values-bs/strings.xml
+++ b/res/values-bs/strings.xml
@@ -160,7 +160,7 @@
     <string name="dialog_cancel" msgid="692365061128351656">"Otkaži"</string>
     <string name="dialog_report" msgid="7616428760369876209">"Prijavi"</string>
     <string name="dialog_dismiss" msgid="1382550604990470119">"Odbaci"</string>
-    <string name="spaceIsLow_content" product="default" msgid="4522771065344332702">"Vaša SD kartica je skoro puna. Promijenite postavku kvaliteta ili izbrišite nekoliko slika ili drugih datoteka."</string>
+    <string name="spaceIsLow_content" product="default" msgid="4522771065344332702">"Vaša SD kartica je skoro puna. Promijenite postavku kvaliteta ili izbrišite nekoliko slika ili drugih fajlova."</string>
     <string name="video_reach_size_limit" msgid="9196836111505731836">"Dostignut limit za veličinu videozapisa."</string>
     <string name="pano_too_fast_prompt" msgid="2503148095578052177">"Prebrzo kretanje"</string>
     <string name="pano_dialog_prepare_preview" msgid="4445235163599534263">"Pripremanje panorame"</string>
@@ -208,13 +208,13 @@
     <string name="photo_accessibility_peek" msgid="5934133371001677250">"Slika snimljena"</string>
     <string name="video_accessibility_peek" msgid="7845916149291383132">"Snimanje videozapisa"</string>
     <string name="accessibility_unlock_to_camera" msgid="1251880974313179442">"Otključati za otvaranje kamere"</string>
-    <string name="media_date_content_description" msgid="2155634843596817141">"Datum i vrijeme kada je medijska datoteka snimljena: %s"</string>
+    <string name="media_date_content_description" msgid="2155634843596817141">"Datum i vrijeme kada je medijski fajl snimljen: %s"</string>
     <string name="photo_date_content_description" msgid="5705865897898465619">"Datum i vrijeme kada je slika snimljena: %s"</string>
     <string name="video_date_content_description" msgid="2151884014634284456">"Datum i vrijeme kada je videozapis snimljen: %s"</string>
     <string name="panorama_date_content_description" msgid="990703578639006144">"Datum i vrijeme kada je panorama snimljena: %s"</string>
     <string name="photosphere_date_content_description" msgid="4183741743409007876">"Datum i vrijeme kada je foto-sfera snimljena: %s"</string>
     <string name="refocus_date_content_description" msgid="5630960320424345547">"Datum i vrijeme kada je snimljena slika sa efektom s izoštrenim objektom: %s"</string>
-    <string name="media_processing_content_description" msgid="8138587719107183754">"Medijske datoteke se obrađuju"</string>
+    <string name="media_processing_content_description" msgid="8138587719107183754">"Medijski fajlovi se obrađuju"</string>
     <string name="accessibility_mode_list_toggle" msgid="4784230103566918645">"Prebaci na spisak načina rada"</string>
     <string name="btn_mode_list_toggle" msgid="3986242443098400164">"Spisak načina rada"</string>
     <string name="accessibility_filmstrip_toggle" msgid="6966978483643396442">"Prebaci na prikaz u vidu filmske trake"</string>
@@ -283,7 +283,7 @@
     <string name="camera_menu_settings_label" msgid="3862756725328016822">"POSTAVKE"</string>
     <string name="create_tiny_planet" msgid="5186918191372107343">"Snimi Malu planetu"</string>
     <string name="saving_tiny_planet" msgid="8828265180177375494">"Spremanje Male planete…"</string>
-    <string name="tiny_planet_zoom" msgid="2985522360577158474">"Uvećavanje"</string>
+    <string name="tiny_planet_zoom" msgid="2985522360577158474">"Zumiranje"</string>
     <string name="tiny_planet_rotate" msgid="5445336705705350004">"Rotiranje"</string>
     <string name="photo_editor" msgid="1521994560971367225">"Uređivač slika"</string>
     <string name="crop_save" msgid="2841974981340098579">"Sačuvaj"</string>
@@ -329,7 +329,7 @@
     <string name="done_button_description" msgid="1334963435441544592">"Završi"</string>
     <string name="retake_button_description" msgid="4234613030674787714">"Ponovo snimi"</string>
     <string name="review_button_description" msgid="7932122063748430080">"Pregled"</string>
-    <string name="share_button_description" msgid="5108508790540832053">"Podijeli"</string>
+    <string name="share_button_description" msgid="5108508790540832053">"Dijeli"</string>
     <string name="view_button_description" msgid="4985768837891362075">"Pregled"</string>
     <string name="edit_button_description" msgid="98550816724901925">"Uredi"</string>
     <string name="delete_button_description" msgid="2251065309677200911">"Izbriši"</string>
@@ -373,7 +373,7 @@
     <string name="share_to" msgid="5144911209144798122">"Podijeliti koristeći"</string>
     <string name="edit_with" msgid="615569327230783971">"Urediti koristeći"</string>
     <string name="startup_dialog_button_next" msgid="1011831256978228993">"DALJE"</string>
-    <string name="confirm_button_text" msgid="7389949384482206814">"UREDU, SHVATIO SAM"</string>
+    <string name="confirm_button_text" msgid="7389949384482206814">"UREDU, RAZUMIJEM"</string>
     <string name="full_sensor_4x3_aspect_ratio" msgid="1270461419743888925">"Podudaranje sa senzorom \n(4:3)"</string>
     <string name="cropped_sensor_16x9_aspect_ratio" msgid="4742161537633251795">"Senzor će izrezati sliku\n(16:9)"</string>
     <string name="pref_boolean_false" msgid="461317129020087333">"0"</string>
diff --git a/res/values-de/strings.xml b/res/values-de/strings.xml
index cee025d..f73580e 100644
--- a/res/values-de/strings.xml
+++ b/res/values-de/strings.xml
@@ -348,7 +348,7 @@
     <string name="setting_default_camera" msgid="6954076799301004779">"Standardkamera"</string>
     <string name="setting_google_help_and_feedback" msgid="2079580537079242775">"Hilfe &amp; Feedback"</string>
     <string name="processing_hdr_plus" msgid="9160093263037540304">"HDR+ wird verarbeitet…"</string>
-    <string name="open_source_licenses" msgid="2169711954264883060">"Open-Source-Lizenzen"</string>
+    <string name="open_source_licenses" msgid="2169711954264883060">"Open Source-Lizenzen"</string>
     <string name="pref_category_general" msgid="6737748849700581019">"Allgemeine Einstellungen"</string>
     <string name="pref_category_resolution_quality" msgid="6641462402321962896">"Auflösung &amp; Qualität"</string>
     <string name="pref_category_about" msgid="1966255405679342337">"Info"</string>
diff --git a/res/values-en-rCA/strings.xml b/res/values-en-rCA/strings.xml
new file mode 100644
index 0000000..5c5627a
--- /dev/null
+++ b/res/values-en-rCA/strings.xml
@@ -0,0 +1,382 @@
+<?xml version="1.0" encoding="UTF-8"?>
+<!--  Copyright (C) 2007 The Android Open Source Project
+
+     Licensed under the Apache License, Version 2.0 (the "License");
+     you may not use this file except in compliance with the License.
+     You may obtain a copy of the License at
+
+          http://www.apache.org/licenses/LICENSE-2.0
+
+     Unless required by applicable law or agreed to in writing, software
+     distributed under the License is distributed on an "AS IS" BASIS,
+     WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+     See the License for the specific language governing permissions and
+     limitations under the License.
+ -->
+
+<resources xmlns:android="http://schemas.android.com/apk/res/android"
+    xmlns:xliff="urn:oasis:names:tc:xliff:document:1.2">
+    <string name="app_name" msgid="1175086483881127797">"Camera"</string>
+    <string name="video_camera_label" msgid="1723708322021743770">"Camcorder"</string>
+    <string name="details_ms" msgid="6618163484662724641">"%1$02d:%2$02d"</string>
+    <string name="details_hms" msgid="4842276230698703554">"%1$d:%2$02d:%3$02d"</string>
+    <string name="set_image" msgid="3969690281401045698">"Set picture as"</string>
+    <string name="delete" msgid="2714492172818940424">"Delete"</string>
+    <string name="share" msgid="8581089487762243115">"Share"</string>
+    <string name="share_panorama" msgid="3558466186935359444">"Share panorama"</string>
+    <string name="share_as_photo" msgid="4831213580709167218">"Share as photo"</string>
+    <string name="deleted" msgid="2036165115527228127">"Deleted"</string>
+    <string name="undo" msgid="5110048345890050107">"UNDO"</string>
+    <string name="details" msgid="4404020741542549488">"Details"</string>
+    <string name="close" msgid="4826166926297479820">"Close"</string>
+    <string name="show_on_map" msgid="8542853913632649160">"Show on map"</string>
+    <string name="rotate_left" msgid="2618440058490662604">"Rotate left"</string>
+    <string name="rotate_right" msgid="4896096424267838355">"Rotate right"</string>
+    <string name="edit" msgid="2776879395749004347">"Edit"</string>
+    <string name="crop_action" msgid="6933589718464132714">"Crop"</string>
+    <string name="trim_action" msgid="4736803320203951827">"Trim"</string>
+    <string name="set_as" msgid="5469055085024870081">"Set as"</string>
+    <string name="video_err" msgid="1562566029875081552">"Cannot play video"</string>
+    <string name="title" msgid="8061744305671964703">"Title"</string>
+    <string name="description" msgid="8193138501982849808">"Description"</string>
+    <string name="time" msgid="5248213506417024287">"Time"</string>
+    <string name="location" msgid="564326205780827668">"Location"</string>
+    <string name="path" msgid="5927003361865586353">"Path"</string>
+    <string name="width" msgid="7045750687833828758">"Width"</string>
+    <string name="height" msgid="5186001199353423689">"Height"</string>
+    <string name="orientation" msgid="3883761294106680270">"Orientation"</string>
+    <string name="duration" msgid="5316211067383665008">"Duration"</string>
+    <string name="mimetype" msgid="6415940055077963944">"MIME type"</string>
+    <string name="file_size" msgid="6841070748357980676">"File size"</string>
+    <string name="maker" msgid="698691509121545856">"Maker"</string>
+    <string name="model" msgid="8547493604023069452">"Model"</string>
+    <string name="flash" msgid="995041910749174196">"Flash"</string>
+    <string name="aperture" msgid="2453802098282814022">"Aperture"</string>
+    <string name="focal_length" msgid="8351221512187346229">"Focal Length"</string>
+    <string name="white_balance" msgid="1600142743496129085">"White balance"</string>
+    <string name="exposure_time" msgid="949787291620767754">"Exposure time"</string>
+    <string name="iso" msgid="8578773821062054902">"ISO"</string>
+    <string name="unit_mm" msgid="5210344300697638286">"mm"</string>
+    <string name="manual" msgid="2444400953521760140">"Manual"</string>
+    <string name="auto" msgid="2552649885114400474">"Auto"</string>
+    <string name="flash_on" msgid="6573457197393807642">"Flash fired"</string>
+    <string name="flash_off" msgid="7889323512830926273">"No flash"</string>
+    <string name="unknown" msgid="564184550182858146">"Unknown"</string>
+    <string name="try_to_set_local_album_available_offline" msgid="3363125545009254117">"This item is stored locally and available offline."</string>
+    <string name="please_wait" msgid="1416313324505140068">"Please wait"</string>
+    <string name="camera_error_title" msgid="6200558085072670067">"Camera error"</string>
+    <string name="error_cannot_connect_camera" msgid="2713059773224193128">"Can\'t connect to the camera."</string>
+    <string name="error_camera_disabled" msgid="5582398275657419692">"Camera has been disabled because of security policies."</string>
+    <string name="error_media_storage_failure" msgid="7711687330673245629">"There was a problem saving your photo or video."</string>
+    <string name="error_permissions" msgid="3454167403425651254">"The app does not have critical permissions needed to run. Please check your permissions settings."</string>
+    <string name="reason_storage_failure" msgid="6818898304774654969">"Photo storage failure."</string>
+    <string name="wait" msgid="765601745709933047">"Please wait…"</string>
+    <string name="no_storage" product="default" msgid="5922012950780548098">"Insert an SD card before using the camera."</string>
+    <string name="preparing_sd" product="default" msgid="7435693655017362767">"Preparing SD card…"</string>
+    <string name="access_sd_fail" product="default" msgid="2634861611082499811">"Couldn\'t access SD card."</string>
+    <string name="time_lapse_title" msgid="3267978566401228497">"Time lapse recording"</string>
+    <string name="feedback_description_camera_access" msgid="419090951070170132">"The app couldn\'t connect to the camera"</string>
+    <string name="feedback_description_save_photo" msgid="8658767358989083228">"Photo or video did not save to the device."</string>
+    <string name="capturing" msgid="5255164204641920893">"Capturing"</string>
+    <string name="pref_camera_id_title" msgid="4680648115225411185">"Choose camera"</string>
+    <string name="pref_camera_id_entry_back" msgid="6386943973628160510">"Back"</string>
+    <string name="pref_camera_id_entry_front" msgid="6233067010315787044">"Front"</string>
+    <string name="pref_camera_save_location_title" msgid="2344235620113384017">"Save location"</string>
+    <string name="pref_camera_location_label" msgid="8695441802378057719">"LOCATION"</string>
+    <string name="pref_camera_timer_title" msgid="4728838281741571323">"Countdown timer"</string>
+    <!-- no translation found for pref_camera_timer_sound_default (6225207881203007747) -->
+    <skip />
+    <string name="pref_camera_timer_sound_title" msgid="9036987234878551217">"Beep during countdown"</string>
+    <string name="setting_off" msgid="6782191065550276632">"Off"</string>
+    <string name="setting_on" msgid="9086728135773197891">"On"</string>
+    <string name="pref_video_quality_title" msgid="5887153490982738588">"Video quality"</string>
+    <string name="pref_video_time_lapse_frame_interval_title" msgid="4975260837607993569">"Time lapse"</string>
+    <string name="pref_camera_settings_category" msgid="4274141528139077830">"Camera settings"</string>
+    <string name="pref_camcorder_settings_category" msgid="3553148484755353397">"Camcorder settings"</string>
+    <string name="pref_camera_picturesize_title" msgid="686045304547541815">"Picture size"</string>
+    <string name="pref_camera_picturesize_entry_large" msgid="9014447075089601575">"Large"</string>
+    <string name="pref_camera_picturesize_entry_medium" msgid="7708839551627003154">"Medium"</string>
+    <string name="pref_camera_picturesize_entry_small" msgid="2991239656622539068">"Small"</string>
+    <string name="pref_camera_focusmode_title" msgid="3637702747984180030">"Focus mode"</string>
+    <string name="pref_camera_focusmode_entry_auto" msgid="8977409813328199501">"Auto"</string>
+    <string name="pref_camera_focusmode_entry_infinity" msgid="3887667853236656322">"Infinity"</string>
+    <string name="pref_camera_focusmode_entry_macro" msgid="7632276686726851426">"Macro"</string>
+    <string name="pref_camera_focusmode_label_auto" msgid="4884418453600317694">"AUTO"</string>
+    <string name="pref_camera_focusmode_label_infinity" msgid="1673352016120343314">"INFINITY"</string>
+    <string name="pref_camera_focusmode_label_macro" msgid="5065639298027996399">"MACRO"</string>
+    <string name="pref_camera_flashmode_title" msgid="8363803841022314574">"Flash mode"</string>
+    <string name="pref_camera_flashmode_label" msgid="5852483713534762800">"FLASH MODE"</string>
+    <string name="pref_camera_flashmode_entry_auto" msgid="4211992591841657014">"Auto"</string>
+    <string name="pref_camera_flashmode_entry_on" msgid="3519831202665377698">"On"</string>
+    <string name="pref_camera_flashmode_entry_off" msgid="8861322265566617357">"Off"</string>
+    <string name="pref_camera_flashmode_label_auto" msgid="2309144918900450379">"FLASH AUTO"</string>
+    <string name="pref_camera_flashmode_label_on" msgid="373595517770024934">"FLASH ON"</string>
+    <string name="pref_camera_flashmode_label_off" msgid="7175863901446001441">"FLASH OFF"</string>
+    <string name="pref_camera_whitebalance_title" msgid="7962809566612868179">"White balance"</string>
+    <string name="pref_camera_whitebalance_label" msgid="7370366644738746700">"WHITE BALANCE"</string>
+    <string name="pref_camera_whitebalance_entry_auto" msgid="1390631794449502796">"Auto"</string>
+    <string name="pref_camera_whitebalance_entry_incandescent" msgid="1140391575294372706">"Incandescent"</string>
+    <string name="pref_camera_whitebalance_entry_daylight" msgid="757833578153467254">"Daylight"</string>
+    <string name="pref_camera_whitebalance_entry_fluorescent" msgid="5157027611220790970">"Fluorescent"</string>
+    <string name="pref_camera_whitebalance_entry_cloudy" msgid="3569589102226796875">"Cloudy"</string>
+    <string name="pref_camera_whitebalance_label_auto" msgid="4305837287360485369">"AUTO"</string>
+    <string name="pref_camera_whitebalance_label_incandescent" msgid="2860805668879945185">"INCANDESCENT"</string>
+    <string name="pref_camera_whitebalance_label_daylight" msgid="4562002095198912409">"DAYLIGHT"</string>
+    <string name="pref_camera_whitebalance_label_fluorescent" msgid="10552295745391742">"FLUORESCENT"</string>
+    <string name="pref_camera_whitebalance_label_cloudy" msgid="4880793739075193336">"CLOUDY"</string>
+    <string name="pref_camera_scenemode_title" msgid="5709932164781367066">"Scene mode"</string>
+    <string name="pref_camera_scenemode_entry_auto" msgid="9205644316260850379">"Auto"</string>
+    <string name="pref_camera_scenemode_entry_hdr_plus" msgid="6759085555519758794">"HDR+"</string>
+    <string name="pref_camera_scenemode_entry_hdr" msgid="3098836808080630955">"HDR"</string>
+    <string name="pref_camera_scenemode_entry_turn_hdr_plus_on" msgid="1096746750342289067">"HDR+ ON"</string>
+    <string name="pref_camera_scenemode_entry_turn_hdr_plus_off" msgid="2668770361856397834">"HDR+ OFF"</string>
+    <string name="pref_camera_scenemode_entry_turn_hdr_on" msgid="5232394324298489502">"HDR ON"</string>
+    <string name="pref_camera_scenemode_entry_turn_hdr_off" msgid="7694606461440250206">"HDR OFF"</string>
+    <string name="pref_camera_scenemode_entry_action" msgid="5753183620959062015">"Action"</string>
+    <string name="pref_camera_scenemode_entry_night" msgid="3468037364159759991">"Night"</string>
+    <string name="pref_camera_scenemode_entry_sunset" msgid="5884302914893488509">"Sunset"</string>
+    <string name="pref_camera_scenemode_entry_party" msgid="401232668169066415">"Party"</string>
+    <string name="pref_camera_scenemode_label_auto" msgid="2874586883608401615">"NONE"</string>
+    <string name="pref_camera_scenemode_label_action" msgid="1822814017595414923">"ACTION"</string>
+    <string name="pref_camera_scenemode_label_night" msgid="7764371228088101131">"NIGHT"</string>
+    <string name="pref_camera_scenemode_label_sunset" msgid="3443610538453611123">"SUNSET"</string>
+    <string name="pref_camera_scenemode_label_party" msgid="917499272505930322">"PARTY"</string>
+    <string name="pref_camera_countdown_label_off" msgid="3986433580620011481">"TIMER OFF"</string>
+    <string name="pref_camera_countdown_label_one" msgid="7647972711796868848">"1 SECOND"</string>
+    <string name="pref_camera_countdown_label_three" msgid="3154170918067103541">"3 SECONDS"</string>
+    <string name="pref_camera_countdown_label_ten" msgid="4372650985906500604">"10 SECONDS"</string>
+    <string name="pref_camera_countdown_label_fifteen" msgid="8469955900530268867">"15 SECONDS"</string>
+    <string name="not_selectable_in_scene_mode" msgid="3260801086980522611">"Not selectable in scene mode."</string>
+    <string name="pref_exposure_title" msgid="7525751789152582800">"Exposure"</string>
+    <string name="pref_exposure_label" msgid="2604738602400261218">"EXPOSURE"</string>
+    <!-- no translation found for pref_camera_hdr_default (5054955236904902318) -->
+    <skip />
+    <!-- no translation found for pref_camera_hdr_plus_default (4827897029274554907) -->
+    <skip />
+    <string name="pref_camera_hdr_label" msgid="1918040375414771185">"HDR"</string>
+    <string name="pref_camera_id_label_back" msgid="1645608049757733858">"FRONT CAMERA"</string>
+    <string name="pref_camera_id_label_front" msgid="349308803062874842">"BACK CAMERA"</string>
+    <string name="dialog_ok" msgid="774141340500181131">"OK"</string>
+    <string name="dialog_cancel" msgid="692365061128351656">"Cancel"</string>
+    <string name="dialog_report" msgid="7616428760369876209">"Report"</string>
+    <string name="dialog_dismiss" msgid="1382550604990470119">"Dismiss"</string>
+    <string name="spaceIsLow_content" product="default" msgid="4522771065344332702">"Your SD card is running out of space. Change the quality setting or delete some images or other files."</string>
+    <string name="video_reach_size_limit" msgid="9196836111505731836">"Size limit reached."</string>
+    <string name="pano_too_fast_prompt" msgid="2503148095578052177">"Too fast"</string>
+    <string name="pano_dialog_prepare_preview" msgid="4445235163599534263">"Preparing panorama"</string>
+    <string name="pano_dialog_panorama_failed" msgid="6772546547048693619">"Couldn\'t save panorama."</string>
+    <string name="pano_dialog_title" msgid="6662642763395425145">"Panorama"</string>
+    <string name="pano_capture_indication" msgid="4002128831255023954">"Capturing panorama"</string>
+    <string name="pano_dialog_waiting_previous" msgid="2646847402743245320">"Waiting for previous panorama"</string>
+    <string name="pano_review_saving_indication_str" msgid="4691771283450663293">"Saving…"</string>
+    <string name="pano_review_rendering" msgid="2743087719999377155">"Rendering panorama"</string>
+    <string name="tap_to_focus" msgid="3519718196270593468">"Touch to focus."</string>
+    <string name="pref_video_effect_title" msgid="594570613431209010">"Effects"</string>
+    <string name="effect_none" msgid="3102797925086872636">"None"</string>
+    <string name="effect_goofy_face_squeeze" msgid="1362021544829311452">"Squeeze"</string>
+    <string name="effect_goofy_face_big_eyes" msgid="9220121522816762649">"Big eyes"</string>
+    <string name="effect_goofy_face_big_mouth" msgid="2064008284599552683">"Big mouth"</string>
+    <string name="effect_goofy_face_small_mouth" msgid="3105849596912069261">"Small mouth"</string>
+    <string name="effect_goofy_face_big_nose" msgid="6936976307035428164">"Big nose"</string>
+    <string name="effect_goofy_face_small_eyes" msgid="558042211252573238">"Small eyes"</string>
+    <string name="effect_backdropper_space" msgid="9133825395915767627">"In space"</string>
+    <string name="effect_backdropper_sunset" msgid="7354053769863638757">"Sunset"</string>
+    <string name="effect_backdropper_gallery" msgid="2333888391153564920">"Your video"</string>
+    <string name="video_snapshot_hint" msgid="2707403607250082339">"Touch to take photo while recording."</string>
+    <string name="video_recording_started" msgid="3374878415050991030">"Video recording has started."</string>
+    <string name="video_recording_stopped" msgid="4658626532857624974">"Video recording has stopped."</string>
+    <string name="clear_effects" msgid="6192797848995967992">"Clear effects"</string>
+    <string name="effect_silly_faces" msgid="7952713419757286453">"SILLY FACES"</string>
+    <string name="effect_background" msgid="1358432220077975015">"BACKGROUND"</string>
+    <string name="accessibility_shutter_button" msgid="6040483605347230438">"Shutter"</string>
+    <string name="accessibility_cancel_button" msgid="5679989494636116448">"Cancel"</string>
+    <string name="accessibility_menu_button" msgid="7692103503958544723">"Menu button"</string>
+    <string name="accessibility_check_box" msgid="1084094675439953723">"%1$s tick box"</string>
+    <string name="accessibility_switch_to_camera" msgid="4518394037216725274">"Switch to photo"</string>
+    <string name="accessibility_switch_to_video" msgid="8174781871592793967">"Switch to video"</string>
+    <string name="accessibility_switch_to_panorama" msgid="8322228859117808037">"Switch to panorama"</string>
+    <string name="accessibility_switch_to_photo_sphere" msgid="5803217570370854725">"Switch to Photo Sphere"</string>
+    <string name="accessibility_switch_to_gcam" msgid="7562625440767034695">"Switch to high quality"</string>
+    <string name="accessibility_switch_to_refocus" msgid="6796169367953860106">"Switch to Refocus"</string>
+    <string name="accessibility_review_cancel" msgid="5462850829869569629">"Review cancel"</string>
+    <string name="accessibility_review_ok" msgid="3486465319880320270">"Review done"</string>
+    <string name="accessibility_review_retake" msgid="2547112860787022130">"Review retake"</string>
+    <string name="accessibility_mode_options" msgid="6376831760155403217">"Options"</string>
+    <string name="accessibility_mode_list_hidden" msgid="3743267380450401866">"Mode list closed"</string>
+    <string name="accessibility_mode_list_shown" msgid="5284322142734069179">"Mode list open"</string>
+    <string name="media_accessibility_peek" msgid="234540330161031946">"Capture taken"</string>
+    <string name="photo_accessibility_peek" msgid="5934133371001677250">"Photo taken"</string>
+    <string name="video_accessibility_peek" msgid="7845916149291383132">"Video taken"</string>
+    <string name="accessibility_unlock_to_camera" msgid="1251880974313179442">"Unlock to Camera"</string>
+    <string name="media_date_content_description" msgid="2155634843596817141">"Media taken on %s"</string>
+    <string name="photo_date_content_description" msgid="5705865897898465619">"Photo taken on %s"</string>
+    <string name="video_date_content_description" msgid="2151884014634284456">"Video taken on %s"</string>
+    <string name="panorama_date_content_description" msgid="990703578639006144">"Panorama taken on %s"</string>
+    <string name="photosphere_date_content_description" msgid="4183741743409007876">"Photo Sphere taken on %s"</string>
+    <string name="refocus_date_content_description" msgid="5630960320424345547">"Lens blur taken on %s"</string>
+    <string name="media_processing_content_description" msgid="8138587719107183754">"Media processing"</string>
+    <string name="accessibility_mode_list_toggle" msgid="4784230103566918645">"Toggle mode list"</string>
+    <string name="btn_mode_list_toggle" msgid="3986242443098400164">"Mode list"</string>
+    <string name="accessibility_filmstrip_toggle" msgid="6966978483643396442">"Toggle filmstrip"</string>
+    <string name="btn_filmstrip_toggle" msgid="3666693972882351490">"Filmstrip"</string>
+    <string name="accessibility_mode_zoom_plus" msgid="4967389173992713073">"Zoom in"</string>
+    <string name="btn_zoom_plus" msgid="4645138949375961656">"Z+"</string>
+    <string name="accessibility_mode_zoom_minus" msgid="8850636036927992409">"Zoom out"</string>
+    <string name="btn_zoom_minus" msgid="5436240345362098272">"Z-"</string>
+    <string name="accessibility_zoom_announcement" msgid="6976673411698319811">"Zoom value is %.1f"</string>
+    <string name="capital_on" msgid="1118214824959797269">"ON"</string>
+    <string name="capital_off" msgid="3020696135020167263">"OFF"</string>
+    <string name="video_control_play" msgid="6895236811408921715">"Play Video"</string>
+    <string name="pref_video_time_lapse_frame_interval_off" msgid="3909611941842585497">"Off"</string>
+    <string name="pref_video_time_lapse_frame_interval_500" msgid="1425296755074319221">"0.5 seconds"</string>
+    <string name="pref_video_time_lapse_frame_interval_1000" msgid="9126255690984179200">"1 second"</string>
+    <string name="pref_video_time_lapse_frame_interval_1500" msgid="5793250074165436905">"1.5 seconds"</string>
+    <string name="pref_video_time_lapse_frame_interval_2000" msgid="1821755013078449188">"2 seconds"</string>
+    <string name="pref_video_time_lapse_frame_interval_2500" msgid="8027471301321122045">"2.5 seconds"</string>
+    <string name="pref_video_time_lapse_frame_interval_3000" msgid="1411114492405867872">"3 seconds"</string>
+    <string name="pref_video_time_lapse_frame_interval_4000" msgid="1197483421014140132">"4 seconds"</string>
+    <string name="pref_video_time_lapse_frame_interval_5000" msgid="7211885329755347592">"5 seconds"</string>
+    <string name="pref_video_time_lapse_frame_interval_6000" msgid="6665825017557898190">"6 seconds"</string>
+    <string name="pref_video_time_lapse_frame_interval_10000" msgid="1126841483618922521">"10 seconds"</string>
+    <string name="pref_video_time_lapse_frame_interval_12000" msgid="8769265988037327085">"12 seconds"</string>
+    <string name="pref_video_time_lapse_frame_interval_15000" msgid="1452711342185926617">"15 seconds"</string>
+    <string name="pref_video_time_lapse_frame_interval_24000" msgid="2505505645705111419">"24 seconds"</string>
+    <string name="pref_video_time_lapse_frame_interval_30000" msgid="3965378176246680626">"0.5 minutes"</string>
+    <string name="pref_video_time_lapse_frame_interval_60000" msgid="1878467100201983878">"1 minute"</string>
+    <string name="pref_video_time_lapse_frame_interval_90000" msgid="496651530019049822">"1.5 minutes"</string>
+    <string name="pref_video_time_lapse_frame_interval_120000" msgid="126293364329503816">"2 minutes"</string>
+    <string name="pref_video_time_lapse_frame_interval_150000" msgid="3469164780802564276">"2.5 minutes"</string>
+    <string name="pref_video_time_lapse_frame_interval_180000" msgid="6840421790710639463">"3 minutes"</string>
+    <string name="pref_video_time_lapse_frame_interval_240000" msgid="1682865866425206481">"4 minutes"</string>
+    <string name="pref_video_time_lapse_frame_interval_300000" msgid="6068734332915957652">"5 minutes"</string>
+    <string name="pref_video_time_lapse_frame_interval_360000" msgid="4692565393277579688">"6 minutes"</string>
+    <string name="pref_video_time_lapse_frame_interval_600000" msgid="7109530398883649472">"10 minutes"</string>
+    <string name="pref_video_time_lapse_frame_interval_720000" msgid="259321148909130247">"12 minutes"</string>
+    <string name="pref_video_time_lapse_frame_interval_900000" msgid="6814816608134052996">"15 minutes"</string>
+    <string name="pref_video_time_lapse_frame_interval_1440000" msgid="5691479246748705053">"24 minutes"</string>
+    <string name="pref_video_time_lapse_frame_interval_1800000" msgid="8331728629455012478">"0.5 hours"</string>
+    <string name="pref_video_time_lapse_frame_interval_3600000" msgid="4829442147263610121">"1 hour"</string>
+    <string name="pref_video_time_lapse_frame_interval_5400000" msgid="7011488725038113884">"1.5 hours"</string>
+    <string name="pref_video_time_lapse_frame_interval_7200000" msgid="7399563587870916008">"2 hours"</string>
+    <string name="pref_video_time_lapse_frame_interval_9000000" msgid="1545856778907835970">"2.5 hours"</string>
+    <string name="pref_video_time_lapse_frame_interval_10800000" msgid="4064231412857457518">"3 hours"</string>
+    <string name="pref_video_time_lapse_frame_interval_14400000" msgid="5174457951350690217">"4 hours"</string>
+    <string name="pref_video_time_lapse_frame_interval_18000000" msgid="5091441456160949740">"5 hours"</string>
+    <string name="pref_video_time_lapse_frame_interval_21600000" msgid="6924571987775154098">"6 hours"</string>
+    <string name="pref_video_time_lapse_frame_interval_36000000" msgid="6959912631566981301">"10 hours"</string>
+    <string name="pref_video_time_lapse_frame_interval_43200000" msgid="6426833030111269499">"12 hours"</string>
+    <string name="pref_video_time_lapse_frame_interval_54000000" msgid="6688725497680331090">"15 hours"</string>
+    <string name="pref_video_time_lapse_frame_interval_86400000" msgid="5510320806095156153">"24 hours"</string>
+    <string name="time_lapse_seconds" msgid="7319683099532506270">"seconds"</string>
+    <string name="time_lapse_minutes" msgid="5325447383033224679">"minutes"</string>
+    <string name="time_lapse_hours" msgid="5294001144133261436">"hours"</string>
+    <string name="time_lapse_interval_set" msgid="2418594453248958440">"Done"</string>
+    <string name="set_time_interval" msgid="2531393962847535331">"Set Time Interval"</string>
+    <string name="set_time_interval_help" msgid="64145154088021389">"Time lapse feature is off. Turn it on to set time interval."</string>
+    <string name="set_duration" msgid="1638453882581604341">"Set duration in seconds"</string>
+    <string name="count_down_title_text" msgid="7586031110595513050">"Counting down to take a photo"</string>
+    <string name="remember_location_title" msgid="3045040613094030429">"Remember photo locations?"</string>
+    <string name="remember_location_prompt" msgid="3006013504489919474">"Tag your photos and videos with the locations where they\'re taken."</string>
+    <string name="remember_location_no" msgid="4412802756840226925">"No, thanks"</string>
+    <string name="remember_location_yes" msgid="4339424460683531388">"Yes"</string>
+    <string name="camera_menu_more_label" msgid="7951917844735828365">"MORE OPTIONS"</string>
+    <string name="camera_menu_settings_label" msgid="3862756725328016822">"SETTINGS"</string>
+    <string name="create_tiny_planet" msgid="5186918191372107343">"Create Tiny Planet"</string>
+    <string name="saving_tiny_planet" msgid="8828265180177375494">"Saving Tiny Planet …"</string>
+    <string name="tiny_planet_zoom" msgid="2985522360577158474">"Zoom"</string>
+    <string name="tiny_planet_rotate" msgid="5445336705705350004">"Rotate"</string>
+    <string name="photo_editor" msgid="1521994560971367225">"Photo Editor"</string>
+    <string name="crop_save" msgid="2841974981340098579">"Save"</string>
+    <string name="cannot_load_image" msgid="4100136187076585580">"Cannot load the image!"</string>
+    <string name="switch_photo_filmstrip" msgid="1448511001008888767">"Filmstrip view"</string>
+    <string name="setting_wallpaper" msgid="2397759659347872725">"Setting wallpaper"</string>
+    <string name="mode_settings" msgid="2021937261522670921">"Settings"</string>
+    <string name="mode_camera" msgid="279763925715250603">"Camera"</string>
+    <string name="mode_video" msgid="8633929034048169139">"Video"</string>
+    <string name="mode_photosphere" msgid="5082338476237291833">"Photo Sphere"</string>
+    <string name="mode_timelapse" msgid="1517168724627815453">"Time Lapse"</string>
+    <string name="mode_wideangle" msgid="1099640345041696830">"Wide Angle"</string>
+    <string name="mode_panorama" msgid="6882648621305828861">"Panorama"</string>
+    <string name="mode_refocus" msgid="172192967119469061">"Lens Blur"</string>
+    <string name="mode_camera_desc" msgid="3670807361165657278">"Switch to Camera Mode"</string>
+    <string name="mode_video_desc" msgid="4058407412929464689">"Switch to Video Camera"</string>
+    <string name="mode_photosphere_desc" msgid="2403816283825579161">"Switch to Photo Sphere Mode"</string>
+    <string name="mode_panorama_desc" msgid="6023020404237519590">"Switch to Panorama Mode"</string>
+    <string name="mode_refocus_desc" msgid="6171183297515508465">"Switch to Lens Blur Mode"</string>
+    <string name="settings_open_desc" msgid="6914471293841793766">"Open settings"</string>
+    <string name="settings_close_desc" msgid="3095831199632813127">"Close settings"</string>
+    <string name="hdr_plus_off_desc" msgid="5301287296717144319">"HDR Plus off"</string>
+    <string name="hdr_plus_on_desc" msgid="8204780034508139909">"HDR Plus on"</string>
+    <string name="hdr_off_desc" msgid="7921924739852874675">"HDR off"</string>
+    <string name="hdr_on_desc" msgid="4591284110249047558">"HDR on"</string>
+    <string name="flash_off_desc" msgid="7151559466286106797">"Flash off"</string>
+    <string name="flash_auto_desc" msgid="3009043125539675717">"Flash auto"</string>
+    <string name="flash_on_desc" msgid="930372145324854699">"Flash on"</string>
+    <string name="hdr_plus_flash_off_desc" msgid="5335888906983788789">"HDR+ flash off"</string>
+    <string name="hdr_plus_flash_auto_desc" msgid="4812200236263011537">"HDR+ flash auto"</string>
+    <string name="hdr_plus_flash_on_desc" msgid="8323389161987561284">"HDR+ flash on"</string>
+    <string name="torch_on_desc" msgid="3069836196559213365">"Torch on"</string>
+    <string name="torch_off_desc" msgid="8304675202998742618">"Torch off"</string>
+    <string name="camera_id_back_desc" msgid="3566327490758890635">"Back camera"</string>
+    <string name="camera_id_front_desc" msgid="7497517948130254220">"Front camera"</string>
+    <string name="grid_lines_off_desc" msgid="2022385817190451353">"Grid lines off"</string>
+    <string name="grid_lines_on_desc" msgid="4601540461914364817">"Grid lines on"</string>
+    <string name="countdown_timer_off" msgid="1663008439564495948">"Countdown timer is off"</string>
+    <string name="countdown_timer_duration_3s" msgid="7435393834886072664">"Countdown timer duration is set to 3 seconds"</string>
+    <string name="countdown_timer_duration_10s" msgid="9085308782250002795">"Countdown timer duration is set to 10 seconds"</string>
+    <string name="more_options_desc" msgid="4628738800610478353">"More Options"</string>
+    <string name="cancel_button_description" msgid="3801167024006905033">"Cancel"</string>
+    <string name="done_button_description" msgid="1334963435441544592">"Done"</string>
+    <string name="retake_button_description" msgid="4234613030674787714">"Retake"</string>
+    <string name="review_button_description" msgid="7932122063748430080">"Review"</string>
+    <string name="share_button_description" msgid="5108508790540832053">"Share"</string>
+    <string name="view_button_description" msgid="4985768837891362075">"View"</string>
+    <string name="edit_button_description" msgid="98550816724901925">"Edit"</string>
+    <string name="delete_button_description" msgid="2251065309677200911">"Delete"</string>
+    <string name="manual_exposure_compensation_desc" msgid="5595219532556566042">"Manual Exposure Compensation"</string>
+    <string name="exposure_compensation_desc_n2" msgid="8957966533506294324">"Exposure Compensation -2"</string>
+    <string name="exposure_compensation_desc_n1" msgid="3035027224866688267">"Exposure Compensation -1"</string>
+    <string name="exposure_compensation_desc_0" msgid="2820273752287040523">"Exposure Compensation 0"</string>
+    <string name="exposure_compensation_desc_p1" msgid="2328275401634452554">"Exposure Compensation +1"</string>
+    <string name="exposure_compensation_desc_p2" msgid="4555277824096107142">"Exposure Compensation +2"</string>
+    <string name="button_change_announcement" msgid="3759686152778772111">"Button is now %s"</string>
+    <string name="setting_location" msgid="4459859689227893838">"Location"</string>
+    <string name="setting_back_camera_photo" msgid="256738900473265017">"Back camera photo"</string>
+    <string name="setting_back_camera_video" msgid="5220819479408164689">"Back camera video"</string>
+    <string name="setting_front_camera_photo" msgid="4131886734622868637">"Front camera photo"</string>
+    <string name="setting_front_camera_video" msgid="2178799452805359752">"Front camera video"</string>
+    <string name="setting_default_camera" msgid="6954076799301004779">"Default Camera"</string>
+    <string name="setting_google_help_and_feedback" msgid="2079580537079242775">"Help &amp; feedback"</string>
+    <string name="processing_hdr_plus" msgid="9160093263037540304">"Processing HDR+ …"</string>
+    <string name="open_source_licenses" msgid="2169711954264883060">"Open-source licences"</string>
+    <string name="pref_category_general" msgid="6737748849700581019">"General Settings"</string>
+    <string name="pref_category_resolution_quality" msgid="6641462402321962896">"Resolution &amp; quality"</string>
+    <string name="pref_category_about" msgid="1966255405679342337">"About"</string>
+    <string name="pref_title_build_version" msgid="481489988124832651">"Build version"</string>
+    <string name="pref_video_quality_entry_low" msgid="737962621299050603">"Low"</string>
+    <string name="pref_video_quality_entry_high" msgid="1613578418842803393">"High"</string>
+    <string name="pref_video_quality_entry_qcif" msgid="1717816794399266216">"QCIF"</string>
+    <string name="pref_video_quality_entry_cif" msgid="645414019445016434">"CIF"</string>
+    <string name="pref_video_quality_entry_480p" msgid="5880250731066854583">"SD 480p"</string>
+    <string name="pref_video_quality_entry_720p" msgid="4076146428148167262">"HD 720p"</string>
+    <string name="pref_video_quality_entry_1080p" msgid="4539958891524211120">"HD 1080p"</string>
+    <string name="pref_video_quality_entry_qvga" msgid="342600517453781430">"QVGA"</string>
+    <string name="pref_video_quality_entry_2160p" msgid="4522927631413184505">"UHD 4K"</string>
+    <string name="setting_summary_x_megapixels" msgid="6533463462760866830">"%1$s megapixels"</string>
+    <string name="setting_summary_aspect_ratio_and_megapixels" msgid="5828440902461064821">"(%1$d:%2$d) %3$s megapixels"</string>
+    <string name="cling_text_for_refocus_editor_button" msgid="4785017397116829802">"To refocus, touch here"</string>
+    <string name="pref_category_advanced" msgid="5921085080077574872">"Advanced"</string>
+    <string name="pref_camera_exposure_compensation" msgid="4143245817259719147">"Manual exposure"</string>
+    <string name="settings_cling_text" msgid="5368054627268181292">"In Settings, change resolution and quality, or try advanced features."</string>
+    <string name="photo_size_selection_title" msgid="2789753590719172645">"Choose photo size"</string>
+    <string name="photo_aspect_ratio_selection_content" msgid="6668224437962196229">"You can change this later in Settings."</string>
+    <string name="share_to" msgid="5144911209144798122">"Share to"</string>
+    <string name="edit_with" msgid="615569327230783971">"Edit with"</string>
+    <string name="startup_dialog_button_next" msgid="1011831256978228993">"NEXT"</string>
+    <string name="confirm_button_text" msgid="7389949384482206814">"OK, GOT IT"</string>
+    <string name="full_sensor_4x3_aspect_ratio" msgid="1270461419743888925">"Full sensor \n(4:3)"</string>
+    <string name="cropped_sensor_16x9_aspect_ratio" msgid="4742161537633251795">"Cropped sensor \n(16:9)"</string>
+    <string name="pref_boolean_false" msgid="461317129020087333">"0"</string>
+    <string name="pref_boolean_true" msgid="4131945223998878009">"1"</string>
+    <string name="session_saving_image" msgid="8932315404486416826">"Saving..."</string>
+</resources>
diff --git a/res/values-mr/strings.xml b/res/values-mr/strings.xml
index 4255f54..3f54fb1 100644
--- a/res/values-mr/strings.xml
+++ b/res/values-mr/strings.xml
@@ -64,7 +64,7 @@
     <string name="unknown" msgid="564184550182858146">"अज्ञात"</string>
     <string name="try_to_set_local_album_available_offline" msgid="3363125545009254117">"हा आयटम स्थानिकरित्या संचयित केलेला आहे आणि ऑफलाइन उपलब्ध आहे."</string>
     <string name="please_wait" msgid="1416313324505140068">"कृपया प्रतीक्षा करा"</string>
-    <string name="camera_error_title" msgid="6200558085072670067">"कॅमेरा त्रुटी"</string>
+    <string name="camera_error_title" msgid="6200558085072670067">"कॅमेरा एरर"</string>
     <string name="error_cannot_connect_camera" msgid="2713059773224193128">"कॅमेर्‍याशी कनेक्ट करु शकत नाही."</string>
     <string name="error_camera_disabled" msgid="5582398275657419692">"सुरक्षा धोरणांमुळे कॅमेरा अक्षम केला गेला आहे."</string>
     <string name="error_media_storage_failure" msgid="7711687330673245629">"आपला फोटो किंवा व्हिडिओ जतन करण्यात समस्या आली."</string>
diff --git a/res/values-my/strings.xml b/res/values-my/strings.xml
index 458ebb0..7f6524b 100644
--- a/res/values-my/strings.xml
+++ b/res/values-my/strings.xml
@@ -156,7 +156,7 @@
     <string name="pref_camera_hdr_label" msgid="1918040375414771185">"HDR"</string>
     <string name="pref_camera_id_label_back" msgid="1645608049757733858">"အရှေ့ကင်မရာ"</string>
     <string name="pref_camera_id_label_front" msgid="349308803062874842">"နောက်ကင်မရာ"</string>
-    <string name="dialog_ok" msgid="774141340500181131">"အိုကေ"</string>
+    <string name="dialog_ok" msgid="774141340500181131">"OK"</string>
     <string name="dialog_cancel" msgid="692365061128351656">"မလုပ်တော့"</string>
     <string name="dialog_report" msgid="7616428760369876209">"သတင်းပို့ပါ"</string>
     <string name="dialog_dismiss" msgid="1382550604990470119">"ပယ်ရန်"</string>
@@ -373,7 +373,7 @@
     <string name="share_to" msgid="5144911209144798122">"...အား မျှဝေရန်"</string>
     <string name="edit_with" msgid="615569327230783971">"...နှင့် တည်းဖြတ်ရန်"</string>
     <string name="startup_dialog_button_next" msgid="1011831256978228993">"ရှေ့သို့"</string>
-    <string name="confirm_button_text" msgid="7389949384482206814">"အိုကေ၊ ရပါပြီ"</string>
+    <string name="confirm_button_text" msgid="7389949384482206814">"OK၊ ရပါပြီ"</string>
     <string name="full_sensor_4x3_aspect_ratio" msgid="1270461419743888925">"အာရုံခံပုံ အပြည့် \n(4:3)"</string>
     <string name="cropped_sensor_16x9_aspect_ratio" msgid="4742161537633251795">"အာရုံခံကိရိယာမှ ဖြတ်ထား\n(16:9)"</string>
     <string name="pref_boolean_false" msgid="461317129020087333">"၀"</string>
diff --git a/res/values-pt-rPT/strings.xml b/res/values-pt-rPT/strings.xml
index 62cabc2..ce6d617 100644
--- a/res/values-pt-rPT/strings.xml
+++ b/res/values-pt-rPT/strings.xml
@@ -24,7 +24,7 @@
     <string name="delete" msgid="2714492172818940424">"Eliminar"</string>
     <string name="share" msgid="8581089487762243115">"Partilhar"</string>
     <string name="share_panorama" msgid="3558466186935359444">"Partilhar panorama"</string>
-    <string name="share_as_photo" msgid="4831213580709167218">"Partilhar como fotografia"</string>
+    <string name="share_as_photo" msgid="4831213580709167218">"Partilhar como foto"</string>
     <string name="deleted" msgid="2036165115527228127">"Eliminada"</string>
     <string name="undo" msgid="5110048345890050107">"ANULAR"</string>
     <string name="details" msgid="4404020741542549488">"Detalhes"</string>
@@ -67,16 +67,16 @@
     <string name="camera_error_title" msgid="6200558085072670067">"Erro da câmara"</string>
     <string name="error_cannot_connect_camera" msgid="2713059773224193128">"Não é possível ligar à câmara."</string>
     <string name="error_camera_disabled" msgid="5582398275657419692">"Devido às políticas de segurança, a câmara foi desativada."</string>
-    <string name="error_media_storage_failure" msgid="7711687330673245629">"Ocorreu um problema ao guardar a fotografia ou o vídeo."</string>
+    <string name="error_media_storage_failure" msgid="7711687330673245629">"Ocorreu um problema ao guardar a foto ou o vídeo."</string>
     <string name="error_permissions" msgid="3454167403425651254">"A aplicação não tem autorizações críticas que são necessárias para ser executada. Verifique as definições das autorizações."</string>
-    <string name="reason_storage_failure" msgid="6818898304774654969">"Falha no armazenamento da fotografia."</string>
+    <string name="reason_storage_failure" msgid="6818898304774654969">"Falha no armazenamento da foto."</string>
     <string name="wait" msgid="765601745709933047">"Aguarde..."</string>
     <string name="no_storage" product="default" msgid="5922012950780548098">"Insira um cartão SD antes de utilizar a câmara."</string>
     <string name="preparing_sd" product="default" msgid="7435693655017362767">"A preparar cartão SD..."</string>
     <string name="access_sd_fail" product="default" msgid="2634861611082499811">"Não foi possível aceder ao cartão SD."</string>
     <string name="time_lapse_title" msgid="3267978566401228497">"Gravação com intervalo de tempo"</string>
     <string name="feedback_description_camera_access" msgid="419090951070170132">"Não foi possível ligar a aplicação à câmara"</string>
-    <string name="feedback_description_save_photo" msgid="8658767358989083228">"A fotografia ou o vídeo não foi guardado no dispositivo."</string>
+    <string name="feedback_description_save_photo" msgid="8658767358989083228">"A foto ou o vídeo não foi guardado no dispositivo."</string>
     <string name="capturing" msgid="5255164204641920893">"A capturar"</string>
     <string name="pref_camera_id_title" msgid="4680648115225411185">"Escolher câmara"</string>
     <string name="pref_camera_id_entry_back" msgid="6386943973628160510">"Anterior"</string>
@@ -182,7 +182,7 @@
     <string name="effect_backdropper_space" msgid="9133825395915767627">"No espaço"</string>
     <string name="effect_backdropper_sunset" msgid="7354053769863638757">"Pôr do sol"</string>
     <string name="effect_backdropper_gallery" msgid="2333888391153564920">"O seu vídeo"</string>
-    <string name="video_snapshot_hint" msgid="2707403607250082339">"Toque para tirar uma fotografia durante a gravação."</string>
+    <string name="video_snapshot_hint" msgid="2707403607250082339">"Toque para tirar uma foto durante a gravação."</string>
     <string name="video_recording_started" msgid="3374878415050991030">"A gravação de vídeo foi iniciada."</string>
     <string name="video_recording_stopped" msgid="4658626532857624974">"A gravação de vídeo foi interrompida."</string>
     <string name="clear_effects" msgid="6192797848995967992">"Limpar efeitos"</string>
@@ -192,7 +192,7 @@
     <string name="accessibility_cancel_button" msgid="5679989494636116448">"Cancelar"</string>
     <string name="accessibility_menu_button" msgid="7692103503958544723">"Botão do menu"</string>
     <string name="accessibility_check_box" msgid="1084094675439953723">"Caixa de verificação %1$s"</string>
-    <string name="accessibility_switch_to_camera" msgid="4518394037216725274">"Mudar para fotografia"</string>
+    <string name="accessibility_switch_to_camera" msgid="4518394037216725274">"Mudar para foto"</string>
     <string name="accessibility_switch_to_video" msgid="8174781871592793967">"Mudar para vídeo"</string>
     <string name="accessibility_switch_to_panorama" msgid="8322228859117808037">"Mudar para panorama"</string>
     <string name="accessibility_switch_to_photo_sphere" msgid="5803217570370854725">"Mudar para Photo Sphere"</string>
@@ -276,7 +276,7 @@
     <string name="set_time_interval" msgid="2531393962847535331">"Definir intervalo de tempo"</string>
     <string name="set_time_interval_help" msgid="64145154088021389">"A funcionalidade de intervalo de tempo está desativada. Ative-a para definir o intervalo de tempo."</string>
     <string name="set_duration" msgid="1638453882581604341">"Definir a duração em segundos"</string>
-    <string name="count_down_title_text" msgid="7586031110595513050">"Contagem decrescente para tirar uma fotografia"</string>
+    <string name="count_down_title_text" msgid="7586031110595513050">"Contagem decrescente para tirar uma foto"</string>
     <string name="remember_location_title" msgid="3045040613094030429">"Memorizar localizações das fotos?"</string>
     <string name="remember_location_prompt" msgid="3006013504489919474">"Adicione etiquetas às fotos e aos vídeos com as localizações onde foram capturados."</string>
     <string name="remember_location_no" msgid="4412802756840226925">"Não, obrigado"</string>
@@ -370,7 +370,7 @@
     <string name="pref_category_advanced" msgid="5921085080077574872">"Avançadas"</string>
     <string name="pref_camera_exposure_compensation" msgid="4143245817259719147">"Exposição manual"</string>
     <string name="settings_cling_text" msgid="5368054627268181292">"Em Definições, altere a resolução e a qualidade ou experimente as funcionalidades avançadas."</string>
-    <string name="photo_size_selection_title" msgid="2789753590719172645">"Escolha o tamanho da fotografia"</string>
+    <string name="photo_size_selection_title" msgid="2789753590719172645">"Escolha o tamanho da foto"</string>
     <string name="photo_aspect_ratio_selection_content" msgid="6668224437962196229">"Pode alterar esta opção mais tarde em Definições."</string>
     <string name="share_to" msgid="5144911209144798122">"Partilhar com"</string>
     <string name="edit_with" msgid="615569327230783971">"Editar com"</string>
diff --git a/res/values-th/strings.xml b/res/values-th/strings.xml
index 3987528..ce21f9e 100644
--- a/res/values-th/strings.xml
+++ b/res/values-th/strings.xml
@@ -348,7 +348,7 @@
     <string name="setting_default_camera" msgid="6954076799301004779">"กล้องถ่ายรูปเริ่มต้น"</string>
     <string name="setting_google_help_and_feedback" msgid="2079580537079242775">"ความช่วยเหลือและความเห็น"</string>
     <string name="processing_hdr_plus" msgid="9160093263037540304">"กำลังดำเนินการ HDR+ …"</string>
-    <string name="open_source_licenses" msgid="2169711954264883060">"สัญญาอนุญาตสำหรับโอเพนซอร์ส"</string>
+    <string name="open_source_licenses" msgid="2169711954264883060">"ใบอนุญาตโอเพนซอร์ส"</string>
     <string name="pref_category_general" msgid="6737748849700581019">"การตั้งค่าทั่วไป"</string>
     <string name="pref_category_resolution_quality" msgid="6641462402321962896">"ความละเอียดและคุณภาพ"</string>
     <string name="pref_category_about" msgid="1966255405679342337">"เกี่ยวกับ"</string>
diff --git a/src/com/android/camera/CameraActivity.java b/src/com/android/camera/CameraActivity.java
index a89ef1f..110ce16 100644
--- a/src/com/android/camera/CameraActivity.java
+++ b/src/com/android/camera/CameraActivity.java
@@ -1657,7 +1657,7 @@
         mMotionManager = getServices().getMotionManager();
 
         mFirstRunDialog = new FirstRunDialog(this,
-              getAndroidContext(),
+              this /* as context */,
               mResolutionSetting,
               mSettingsManager,
               mOneCameraManager,
@@ -2191,6 +2191,9 @@
         if (mSoundPlayer != null) {
           mSoundPlayer.release();
         }
+        if (mFirstRunDialog != null) {
+            mFirstRunDialog.dismiss();
+        }
         CameraAgentFactory.recycle(CameraAgentFactory.CameraApi.API_1);
         CameraAgentFactory.recycle(CameraAgentFactory.CameraApi.AUTO);
     }
diff --git a/src/com/android/camera/CaptureModule.java b/src/com/android/camera/CaptureModule.java
index 640da4f..00a58cd 100644
--- a/src/com/android/camera/CaptureModule.java
+++ b/src/com/android/camera/CaptureModule.java
@@ -1537,12 +1537,10 @@
 
     /**
      * Returns which way around the camera is facing, based on it's ID.
-     * <p>
-     * TODO: This needs to change so that we store the direction directly in the
-     * settings, rather than a Camera ID.
      */
-    private static Facing getFacingFromCameraId(int cameraId) {
-        return cameraId == 1 ? Facing.FRONT : Facing.BACK;
+    private Facing getFacingFromCameraId(int cameraId) {
+        return mAppController.getCameraProvider().getCharacteristics(cameraId)
+                .isFacingFront() ? Facing.FRONT : Facing.BACK;
     }
 
     private void resetTextureBufferSize() {
diff --git a/src/com/android/camera/DisableCameraReceiver.java b/src/com/android/camera/DisableCameraReceiver.java
index aea6ec5..5237c1d 100644
--- a/src/com/android/camera/DisableCameraReceiver.java
+++ b/src/com/android/camera/DisableCameraReceiver.java
@@ -30,7 +30,7 @@
 // this receiver will be disabled, so it will not run again.
 public class DisableCameraReceiver extends BroadcastReceiver {
     private static final Log.Tag TAG = new Log.Tag("DisableCamRcver");
-    private static final boolean CHECK_BACK_CAMERA_ONLY = true;
+    private static final boolean CHECK_BACK_CAMERA_ONLY = false;
     private static final String ACTIVITIES[] = {
         "com.android.camera.CameraLauncher",
     };
diff --git a/src/com/android/camera/VideoModule.java b/src/com/android/camera/VideoModule.java
index 9a941c7..e8222f6 100644
--- a/src/com/android/camera/VideoModule.java
+++ b/src/com/android/camera/VideoModule.java
@@ -808,7 +808,8 @@
      */
     private static Point getDesiredPreviewSize(CameraCapabilities capabilities,
           CamcorderProfile profile, Point previewScreenSize) {
-        if (capabilities.getSupportedVideoSizes() == null) {
+        if (capabilities.getSupportedVideoSizes() == null ||
+            capabilities.getSupportedVideoSizes().isEmpty()) {
             // Driver doesn't support separate outputs for preview and video.
             return new Point(profile.videoFrameWidth, profile.videoFrameHeight);
         }
diff --git a/src/com/android/camera/captureintent/resource/ResourceConstructedImpl.java b/src/com/android/camera/captureintent/resource/ResourceConstructedImpl.java
index 588b7d4..5e90f40 100644
--- a/src/com/android/camera/captureintent/resource/ResourceConstructedImpl.java
+++ b/src/com/android/camera/captureintent/resource/ResourceConstructedImpl.java
@@ -76,7 +76,7 @@
             AppController appController,
             FatalErrorHandler fatalErrorHandler) {
         final CameraFacingSetting cameraFacingSetting = new CameraFacingSetting(
-                context.getResources(), settingsManager, settingScopeNamespace);
+                context.getResources(), settingsManager, settingScopeNamespace, appController);
         final ResolutionSetting resolutionSetting = new ResolutionSetting(
                 settingsManager, oneCameraManager, context.getContentResolver());
         return new RefCountBase<ResourceConstructed>(new ResourceConstructedImpl(
diff --git a/src/com/android/camera/one/config/OneCameraFeatureConfigCreator.java b/src/com/android/camera/one/config/OneCameraFeatureConfigCreator.java
index 3e0fb9d..dc7f900 100644
--- a/src/com/android/camera/one/config/OneCameraFeatureConfigCreator.java
+++ b/src/com/android/camera/one/config/OneCameraFeatureConfigCreator.java
@@ -131,8 +131,12 @@
     }
 
     private static boolean supportsReprocessing(CameraCharacteristics characteristics) {
-        int maxNumInputStreams = characteristics.get(
+        Integer maxNumInputStreams = characteristics.get(
                 CameraCharacteristics.REQUEST_MAX_NUM_INPUT_STREAMS);
+        if (maxNumInputStreams == null) {
+            Log.e(TAG, "Camera does not have maximum number of input streams.");
+            return false;
+        }
         if (maxNumInputStreams == 0) {
             return false;
         }
diff --git a/src/com/android/camera/settings/CameraFacingSetting.java b/src/com/android/camera/settings/CameraFacingSetting.java
index 1881d7e..8227ad6 100644
--- a/src/com/android/camera/settings/CameraFacingSetting.java
+++ b/src/com/android/camera/settings/CameraFacingSetting.java
@@ -16,6 +16,7 @@
 
 package com.android.camera.settings;
 
+import com.android.camera.app.AppController;
 import com.android.camera.CameraActivity;
 import com.android.camera.one.OneCamera;
 import com.android.camera2.R;
@@ -40,18 +41,24 @@
     public CameraFacingSetting(
             Resources resources,
             SettingsManager settingsManager,
-            String moduleSettingScope) {
+            String moduleSettingScope,
+            AppController appController) {
         mSettingsManager = settingsManager;
 
         mSettingScope = SettingsManager.getModuleSettingScope(moduleSettingScope);
 
         mCameraFacingSettingKey = Keys.KEY_CAMERA_ID;
-        mCameraFacingBackValue =
-                Integer.parseInt(resources.getString(R.string.pref_camera_id_entry_back_value));
-        mCameraFacingFrontValue =
-                Integer.parseInt(resources.getString(R.string.pref_camera_id_entry_front_value));
         mCameraFacingDefaultValue =
                 Integer.parseInt(resources.getString(R.string.pref_camera_id_default));
+
+        if (appController.getCameraProvider().getCharacteristics(mCameraFacingDefaultValue).
+                isFacingFront()) {
+            mCameraFacingFrontValue = 0;
+            mCameraFacingBackValue = 1;
+        } else {
+            mCameraFacingBackValue = 0;
+            mCameraFacingFrontValue = 1;
+        }
     }
 
     @Override
diff --git a/src/com/android/camera/ui/focus/FocusRingView.java b/src/com/android/camera/ui/focus/FocusRingView.java
index 6b5cca0..1b4960d 100644
--- a/src/com/android/camera/ui/focus/FocusRingView.java
+++ b/src/com/android/camera/ui/focus/FocusRingView.java
@@ -172,7 +172,7 @@
         }
 
         if (mPreviewSize != null) {
-            canvas.clipRect(mPreviewSize, Region.Op.REPLACE);
+            canvas.clipRect(mPreviewSize);
         }
 
         mAnimator.draw(canvas);
diff --git a/src/com/android/camera/app/FirstRunDialog.java b/src/com/android/camera/app/FirstRunDialog.java
index d810c4b..91c0570 100644
--- a/src/com/android/camera/app/FirstRunDialog.java
+++ b/src/com/android/camera/app/FirstRunDialog.java
@@ -60,7 +60,7 @@
     /** The hardware manager. */
     private final OneCameraManager mOneCameraManager;
 
     /** The app context. */
     private final Context mContext;
 
     /** The resolution settings. */
@@ -81,13 +81,13 @@
      */
     public FirstRunDialog(
           AppController appController,
-          Context androidContext,
+          Context activityContext,
           ResolutionSetting resolutionSetting,
           SettingsManager settingManager,
           OneCameraManager hardwareManager,
           FirstRunDialogListener listener) {
         mAppController = appController;
-        mContext = androidContext;
+        mContext = activityContext;
         mResolutionSetting = resolutionSetting;
         mSettingsManager = settingManager;
         mOneCameraManager = hardwareManager;
@@ -60,7 +60,7 @@
     private final OneCameraManager mOneCameraManager;
 
-    /** The app context. */
+    /** The activity context. */
     private final Context mContext;
 